# {title}

![{title}](./images/{filename}.png)

## Overview

{overview_description}

## Features

{features_list}

## Key Actions

{actions_section}

{if_has_flows}
## How to: {flow_name}

{flow_steps}
{/if_has_flows}

## Data Display

{data_display_section}

## Related Pages

{navigation_links}

---

*Documentation generated by [docs:generate](https://github.com/binarcode/ai-doc-generator)*
